package ch.bbw.pr.tresorbackend.controller;

import ch.bbw.pr.tresorbackend.model.AuthRequest;
import ch.bbw.pr.tresorbackend.model.AuthResponse;
import ch.bbw.pr.tresorbackend.model.User;
import ch.bbw.pr.tresorbackend.repository.UserRepository;
import ch.bbw.pr.tresorbackend.service.PasswordEncryptionService;
import ch.bbw.pr.tresorbackend.util.JwtUtil;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.web.bind.annotation.*;

@RestController
@AllArgsConstructor
@RequestMapping("/api/auth")
public class AuthController {
    private JwtUtil jwtUtil;
    private UserRepository userRepository;
    private PasswordEncryptionService passwordService;

    @CrossOrigin(origins = "${CROSS_ORIGIN}")
    @PostMapping("/")
    public ResponseEntity<?> authentication(@Valid @RequestBody AuthRequest request) {
        User user = userRepository.findByEmail(request.getEmail()).orElse(null);
        if (user == null || !passwordService.verifyPassword(user, request.getPassword()) ) {
            return ResponseEntity.status(HttpStatus.UNAUTHORIZED).build();
        }
        String token = jwtUtil.generateToken(user);
        return ResponseEntity.ok(new AuthResponse(token));
    }
}