package ch.bbw.pr.tresorbackend.controller;

import ch.bbw.pr.tresorbackend.model.Check2FACode;
import ch.bbw.pr.tresorbackend.model.Generate2FACode;
import ch.bbw.pr.tresorbackend.service.TwoFactorAuthService;
import com.warrenstrange.googleauth.GoogleAuthenticator;
import com.warrenstrange.googleauth.GoogleAuthenticatorKey;
import com.warrenstrange.googleauth.GoogleAuthenticatorQRGenerator;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

@RestController
@AllArgsConstructor
@RequestMapping("/api/2fa")
public class TwoFactorAuthController {

    private TwoFactorAuthService twoFactorAuthService;
    private final GoogleAuthenticator gAuth = new GoogleAuthenticator();


    @CrossOrigin(origins = "${CROSS_ORIGIN}")
    @PostMapping("/generate-secret")
    public ResponseEntity<Map<String, String>> generateSecret(@Valid @RequestBody Generate2FACode generate2FACode) {
        GoogleAuthenticatorKey key = gAuth.createCredentials();
        twoFactorAuthService.addTwoFactorSecretToUser(key.getKey(), generate2FACode.getEmail(), generate2FACode.getPassword());

        String qrUrl = GoogleAuthenticatorQRGenerator.getOtpAuthURL("Tresor", generate2FACode.getEmail(), key);
        Map<String, String> response = Map.of("secret", key.getKey(), "qrUrl", qrUrl);
        return ResponseEntity.ok(response);
    }

    @CrossOrigin(origins = "${CROSS_ORIGIN}")
    @PostMapping("/verify")
    public ResponseEntity<String> verifyCode(@Valid @RequestBody Check2FACode check2FACode) {
        String secret = twoFactorAuthService.getTwoFactorSecretFromUser(check2FACode.getEmail(), check2FACode.getPassword());
        if (secret == null) {
            return ResponseEntity.status(HttpStatus.NOT_FOUND).body("User not found");
        }
        boolean isValid = gAuth.authorize(secret, check2FACode.getCode());
        return isValid ? ResponseEntity.ok("2FA success") : ResponseEntity.status(401).body("Invalid code");
    }
}