import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { loginUser, captchaCheck } from '../../comunication/FetchUser';
import ReCAPTCHA from 'react-google-recaptcha';
import { generate2FACode, verify2FACode } from '../../comunication/TwoFactorAuth';
import { fetchJwtToken } from '../../comunication/JwtToken';

/**
 * LoginUser
 * @author Peter Rutschmann
 */
function LoginUser({ loginValues, setLoginValues }) {
    const navigate = useNavigate();
    const [recaptchaToken, setRecaptchaToken] = useState(null);
    const [code, setCode] = useState(0);


    const handleCaptcha = (token) => {
        setRecaptchaToken(token);
    };

    const handleSubmit = async (e) => {
        e.preventDefault();

        if (!recaptchaToken) {
            alert("Please verify reCAPTCHA");
            return;
        }

        try {
            const captchaData = await captchaCheck(recaptchaToken);

            let isLoginValid = false
            isLoginValid = await loginUser(loginValues);
            if (isLoginValid || captchaData.success) {
                document.getElementById('loginForm').style.display = "none";
                document.getElementById('twofaForm').style.display = "block";
                setLoginValues({ email: loginValues.email, password: loginValues.password });
                return false // that the page doesnt reload
            }
        } catch (error) {
            console.error('Failed to fetch to server:', error.message);
        }
    };

    const verify2FA = async () => {
        const res = await verify2FACode({ loginValues, code });
        if (res) {
            const jwtToken = await fetchJwtToken(loginValues)
            document.cookie = "jwtToken=" + jwtToken;
            navigate('/')
            return
        }
        alert('2fa code not valid');
    };

    return (
        <div>
            <h2>Login user</h2>
            <form id='loginForm' onSubmit={handleSubmit}>
                <section>
                    <aside>
                        <div>
                            <label>Email:</label>
                            <input
                                type="email"
                                value={loginValues.email}
                                onChange={(e) =>
                                    setLoginValues(prevValues => ({ ...prevValues, email: e.target.value }))}
                                required
                                placeholder="Please enter your email *"
                            />
                        </div>
                        <div>
                            <label>Password:</label>
                            <input
                                type="password"
                                value={loginValues.password}
                                onChange={(e) =>
                                    setLoginValues(prevValues => ({ ...prevValues, password: e.target.value }))}
                                required
                                placeholder="Please enter your password *"
                            />
                        </div>
                    </aside>
                </section>
                <ReCAPTCHA
                    sitekey="6LdJj1crAAAAABcEz65x0DUAsuJUBCKwdSi1Mewj"
                    onChange={handleCaptcha}
                />
                <button type="submit">Login</button>
            </form>
            <form id='twofaForm' onSubmit={verify2FA}>
                <h2>2FA</h2>
                <input type="number" value={code} onChange={(e) => setCode(e.target.value)} required />
                <button type="button" onClick={verify2FA}>Check</button>
            </form>
        </div>
    );
}

export default LoginUser;
